@@ -1,14 +1,14 @@
 """
 Components/RecycleGridLayout
-=====================
+============================
 
-:class:`~kivy.uix.recyclegridlayout.RecycleGridLayout` class equivalent. Simplifies working
-with some widget properties. For example:
+:class:`~kivy.uix.recyclegridlayout.RecycleGridLayout` class equivalent.
+Simplifies working with some widget properties. For example:
 
-GridLayout
-----------
+RecycleGridLayout
+-----------------
 
-.. code-block::
+.. code-block:: kv
 
     RecycleGridLayout:
         size_hint_y: None
@@ -22,9 +22,9 @@ GridLayout
                 size: self.size
 
 MDRecycleGridLayout
-------------
+-------------------
 
-.. code-block::
+.. code-block:: kv
 
     MDRecycleGridLayout:
         adaptive_height: True
@@ -85,8 +85,15 @@ Equivalent
 
 from kivy.uix.recyclegridlayout import RecycleGridLayout
 
+from kivymd.theming import ThemableBehavior
 from kivymd.uix import MDAdaptiveWidget
+from kivymd.uix.behaviors import DeclarativeBehavior
 
 
-class MDRecycleGridLayout(RecycleGridLayout, MDAdaptiveWidget):
-    pass
+class MDRecycleGridLayout(
+    DeclarativeBehavior, ThemableBehavior, RecycleGridLayout, MDAdaptiveWidget
+):
+    """
+    Recycle grid layout layout class. For more information, see in the
+    :class:`~kivy.uix.recyclegridlayout.RecycleGridLayout` class documentation.
+    """
