@@ -121,7 +121,6 @@ from kivy.properties import (
 )
 
 from kivymd import uix_path
-from kivymd.theming import ThemableBehavior
 from kivymd.uix.boxlayout import MDBoxLayout
 from kivymd.uix.button import MDRaisedButton
 from kivymd.uix.card import MDSeparator
@@ -145,12 +144,12 @@ class MDSegmentedControlItem(MDLabel):
 
 
 # TODO: Add an attribute for the color of the active segment label.
-class MDSegmentedControl(MDRelativeLayout, ThemableBehavior):
+class MDSegmentedControl(MDRelativeLayout):
     """
     Implements a segmented control panel.
 
-    Relative layout class. For more information, see in the
-    :class:`~kivy.uix.relativelayout.RelativeLayout` class documentation.
+    For more information, see in the
+    :class:`~kivymd.uix.relativelayout.MDRelativeLayout` class documentation.
 
     :Events:
         `on_active`
@@ -159,7 +158,7 @@ class MDSegmentedControl(MDRelativeLayout, ThemableBehavior):
 
     md_bg_color = ColorProperty([0, 0, 0, 0])
     """
-    Background color of the segment panel.
+    Background color of the segment panel in (r, g, b, a) or string format.
 
     .. code-block:: kv
 
@@ -175,7 +174,7 @@ class MDSegmentedControl(MDRelativeLayout, ThemableBehavior):
 
     segment_color = ColorProperty([0, 0, 0, 0])
     """
-    Color of the active segment.
+    Color of the active segment in (r, g, b, a) or string format.
 
     .. code-block:: kv
 
@@ -220,7 +219,8 @@ class MDSegmentedControl(MDRelativeLayout, ThemableBehavior):
 
     separator_color = ColorProperty(None)
     """
-    The color of the separator between the segments.
+    The color of the separator between the segments in (r, g, b, a) or string
+    format.
 
     .. code-block:: kv
 
