@@ -50,6 +50,7 @@ Example with TwoLineAvatarListItem
 
     from kivy.animation import Animation
     from kivy.lang import Builder
+    from kivy.utils import get_color_from_hex
 
     from kivymd.app import MDApp
     from kivymd.uix.list import TwoLineAvatarListItem
@@ -100,7 +101,7 @@ Example with TwoLineAvatarListItem
 
 
     class Example(MDApp):
-        overlay_color = "#6042e4"
+        overlay_color = get_color_from_hex("#6042e4")
 
         def build(self):
             return Builder.load_string(KV)
@@ -156,7 +157,7 @@ Example with FitImage
     from kivy.properties import ColorProperty
 
     from kivymd.app import MDApp
-    from kivymd.utils.fitimage import FitImage
+    from kivymd.uix.fitimage import FitImage
 
     KV = '''
     MDBoxLayout:
@@ -275,7 +276,6 @@ from kivy.properties import (
 )
 
 from kivymd import uix_path
-from kivymd.theming import ThemableBehavior
 from kivymd.uix.behaviors import TouchBehavior
 from kivymd.uix.button import MDIconButton
 from kivymd.uix.list import MDList
@@ -294,7 +294,7 @@ class SelectionIconCheck(MDIconButton):
     icon_check_color = ColorProperty([0, 0, 0, 1])
 
 
-class SelectionItem(ThemableBehavior, MDRelativeLayout, TouchBehavior):
+class SelectionItem(MDRelativeLayout, TouchBehavior):
     selected = BooleanProperty(False)
     """
     Whether or not an item is checked.
@@ -446,7 +446,7 @@ class SelectionItem(ThemableBehavior, MDRelativeLayout, TouchBehavior):
 
     def get_progress_round_pos(self) -> tuple:
         return (
-            self.center_x - self.progress_round_size / 2,
+            (self.pos[0] + self.width / 2) - self.progress_round_size / 2,
             self.center_y - self.progress_round_size / 2,
         )
 
@@ -513,6 +513,11 @@ class SelectionItem(ThemableBehavior, MDRelativeLayout, TouchBehavior):
 
 class MDSelectionList(MDList):
     """
+    Selection list class.
+
+    For more information, see in the
+    :class:`~kivymd.uix.list.MDList` classes documentation.
+
     :Events:
         `on_selected`
             Called when a list item is selected.
@@ -547,7 +552,8 @@ class MDSelectionList(MDList):
 
     icon_bg_color = ColorProperty([1, 1, 1, 1])
     """
-    Background color of the icon that will mark the selected list item.
+    Background color in (r, g, b, a) or string format of the icon that will
+    mark the selected list item.
 
     :attr:`icon_bg_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `[1, 1, 1, 1]`.
@@ -555,7 +561,8 @@ class MDSelectionList(MDList):
 
     icon_check_color = ColorProperty([0, 0, 0, 1])
     """
-    Color of the icon that will mark the selected list item.
+    Color in (r, g, b, a) or string format of the icon that will mark the
+    selected list item.
 
     :attr:`icon_check_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `[1, 1, 1, 1]`.
@@ -563,7 +570,7 @@ class MDSelectionList(MDList):
 
     overlay_color = ColorProperty([0, 0, 0, 0.2])
     """
-    The overlay color of the selected list item..
+    The overlay color in (r, g, b, a) or string format of the selected list item.
 
     :attr:`overlay_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `[0, 0, 0, 0.2]]`.
@@ -579,7 +586,8 @@ class MDSelectionList(MDList):
 
     progress_round_color = ColorProperty(None)
     """
-    Color of the spinner for switching of `selected_mode` mode.
+    Color in (r, g, b, a) or string format of the spinner for switching of
+    `selected_mode` mode.
 
     :attr:`progress_round_color` is an :class:`~kivy.properties.NumericProperty`
     and defaults to `None`.
