@@ -97,9 +97,19 @@ with open(
 
 
 class MDTooltip(ThemableBehavior, HoverBehavior, TouchBehavior):
+    """
+    Tooltip class.
+
+    For more information, see in the
+    :class:`~kivymd.theming.ThemableBehavior and
+    :class:`~kivymd.uix.behaviors.HoverBehavior` and
+    :class:`~kivymd.uix.behaviors.TouchBehavior`
+    classes documentation.
+    """
+
     tooltip_bg_color = ColorProperty(None)
     """
-    Tooltip background color in ``rgba`` format.
+    Tooltip background color in (r, g, b, a) or string format
 
     :attr:`tooltip_bg_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `None`.
@@ -107,7 +117,7 @@ class MDTooltip(ThemableBehavior, HoverBehavior, TouchBehavior):
 
     tooltip_text_color = ColorProperty(None)
     """
-    Tooltip text color in ``rgba`` format.
+    Tooltip text color in (r, g, b, a) or string format
 
     :attr:`tooltip_text_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `None`.
@@ -330,6 +340,15 @@ class MDTooltip(ThemableBehavior, HoverBehavior, TouchBehavior):
 
 
 class MDTooltipViewClass(ThemableBehavior, BoxLayout):
+    """
+    Tooltip view class.
+
+    For more information, see in the
+    :class:`~kivymd.theming.ThemableBehavior` and
+    :class:`~kivy.uix.boxlayout.BoxLayout`
+    classes documentation.
+    """
+
     tooltip_bg_color = ColorProperty(None)
     """
     See :attr:`~MDTooltip.tooltip_bg_color`.
