@@ -14,6 +14,14 @@ from kivy.core.clipboard import Clipboard
 from kivymd.uix.button import MDRectangleFlatButton
 from kivymd.uix.dialog import MDDialog
 
+from kivy.lang.builder import Builder
+
+from kivy.utils import escape_markup
+if RNS.vendor.platformutils.get_platform() == "android":
+    from ui.helpers import multilingual_markup, sig_icon_for_q
+else:
+    from .helpers import multilingual_markup, sig_icon_for_q
+
 if RNS.vendor.platformutils.get_platform() == "android":
     from ui.helpers import ts_format
 else:
@@ -25,6 +33,13 @@ class Announces():
         self.context_dests = []
         self.added_item_dests = []
         self.list = None
+
+        if not self.app.root.ids.screen_manager.has_screen("announces_screen"):
+            self.screen = Builder.load_string(layout_announces_screen)
+            self.screen.app = self.app
+            self.ids = self.screen.ids
+            self.app.root.ids.screen_manager.add_widget(self.screen)
+
         self.fetch_announces()
         self.list = MDList()
         # self.update()
@@ -74,8 +89,28 @@ class Announces():
         for announce in self.announces:
             context_dest = announce["dest"]
             ts = announce["time"]
-            a_data = announce["data"]
+            a_name = announce["name"]
+            a_cost = announce["cost"]
             dest_type = announce["type"]
+            a_rssi = None
+            a_snr = None
+            a_q = None
+
+            link_extras_str = ""
+            link_extras_full = ""
+            if "extras" in announce and announce["extras"] != None:
+                extras = announce["extras"]
+                if "link_stats" in extras:
+                    link_stats = extras["link_stats"]
+                    if "rssi" in link_stats and "snr" in link_stats and "q" in link_stats:
+                        a_rssi = link_stats["rssi"]
+                        a_snr  = link_stats["snr"]
+                        a_q    = link_stats["q"]
+                        if a_rssi != None and a_snr != None and a_q != None:
+                            link_extras_str  = f" ([b]RSSI[/b] {a_rssi} [b]SNR[/b] {a_snr})"
+                            link_extras_full = f"\n[b]Link Quality[/b] {a_q}%[/b]\n[b]RSSI[/b] {a_rssi}\n[b]SNR[/b] {a_snr}"
+
+            sig_icon = multilingual_markup(sig_icon_for_q(a_q).encode("utf-8")).decode("utf-8")
 
             if not context_dest in self.added_item_dests:
                 if self.app.sideband.is_trusted(context_dest):
@@ -83,15 +118,25 @@ class Announces():
                 else:
                     trust_icon = "account-question"
 
-                def gen_info(ts, dest, name, dtype):
+                def gen_info(ts, dest, name, cost, dtype, link_extras):
+                    name = multilingual_markup(escape_markup(str(name)).encode("utf-8")).decode("utf-8")
+                    cost = str(cost)
                     def x(sender):
-                        yes_button = MDRectangleFlatButton(text="OK",font_size=dp(18))
-                        
+                        yes_button = MDRectangleFlatButton(text="OK",font_size=dp(18))    
                         if dtype == "lxmf.delivery":
-                            ad_text = "[size=22dp]LXMF Peer[/size]\n\nReceived: "+ts+"\nAnnounced Name: "+name+"\nAddress: "+RNS.prettyhexrep(dest)
+                            ad_text = "[size=22dp]LXMF Peer[/size]\n\n[b]Received[/b] "+ts+"\n[b]Address[/b] "+RNS.prettyhexrep(dest)+"\n[b]Name[/b] "+name+"\n[b]Stamp Cost[/b] "+cost+link_extras
 
                         if dtype == "lxmf.propagation":
-                            ad_text = "[size=22dp]LXMF Propagation Node[/size]\n\nReceived: "+ts+"\nAddress: "+RNS.prettyhexrep(dest)
+                            if a_name:
+                                disp_name = multilingual_markup(escape_markup(str(a_name)).encode("utf-8")).decode("utf-8")
+                                disp_name = f"\n[b]Name[/b] {disp_name}"
+                            else: disp_name = ""
+                            if a_cost:
+                                disp_cost = str(a_cost)
+                                disp_cost = f"\n[b]Stamp Cost[/b] {disp_cost}"
+                            else: disp_cost = ""
+
+                            ad_text = f"[size=22dp]LXMF Propagation Node[/size]\n\n[b]Received[/b] {ts}\n[b]Address[/b] {RNS.prettyhexrep(dest)+link_extras}{disp_name}{disp_cost}"
 
                         dialog = MDDialog(
                             text=ad_text,
@@ -106,21 +151,24 @@ class Announces():
                         dialog.open()
                     return x
 
-                time_string = time.strftime(ts_format, time.localtime(ts))
+                time_string = sig_icon + "  " + time.strftime(ts_format, time.localtime(ts)) + link_extras_str
+                time_string_plain = time.strftime(ts_format, time.localtime(ts))
 
                 if dest_type == "lxmf.delivery":
-                    disp_name = self.app.sideband.peer_display_name(context_dest)
+                    disp_name = multilingual_markup(escape_markup(str(self.app.sideband.peer_display_name(context_dest))).encode("utf-8")).decode("utf-8")
                     iconl = IconLeftWidget(icon=trust_icon)
 
                 elif dest_type == "lxmf.propagation":
-                    disp_name = "Propagation Node "+RNS.prettyhexrep(context_dest)
+                    if a_name: disp_name = multilingual_markup(escape_markup(str(a_name)).encode("utf-8")).decode("utf-8")
+                    else: disp_name = f"Propagation Node"
+                    disp_name = f"{disp_name} {RNS.prettyhexrep(context_dest)}"
                     iconl = IconLeftWidget(icon="upload-network")
 
                 else:
                     disp_name = "Unknown Announce"
                     iconl = IconLeftWidget(icon="progress-question")
 
-                item = TwoLineAvatarIconListItem(text=time_string, secondary_text=disp_name, on_release=gen_info(time_string, context_dest, a_data, dest_type))
+                item = TwoLineAvatarIconListItem(text=time_string, secondary_text=disp_name, on_release=gen_info(time_string_plain, context_dest, a_name, a_cost, dest_type, link_extras_full))
                 item.add_widget(iconl)
                 item.sb_uid = context_dest
                 item.ts = ts
@@ -222,13 +270,12 @@ class Announces():
                 item.dmenu = MDDropdownMenu(
                     caller=item.iconr,
                     items=dm_items,
-                    position="center",
-                    width_mult=4,
-                    elevation=1,
+                    position="auto",
+                    width=dp(256),
+                    elevation=0,
                     radius=dp(3),
-                    opening_transition="linear",
-                    opening_time=0.0,
                 )
+                item.dmenu.md_bg_color = self.app.color_hover
 
                 def callback_factory(ref):
                     def x(sender):
@@ -242,4 +289,42 @@ class Announces():
                 self.list.add_widget(item, index=len(self.list.children))
 
     def get_widget(self):
-        return self.list
\ No newline at end of file
+        return self.list
+
+layout_announces_screen = """
+MDScreen:
+    name: "announces_screen"
+    
+    BoxLayout:
+        orientation: "vertical"
+
+        MDTopAppBar:
+            title: "Announce Stream"
+            anchor_title: "left"
+            elevation: 0
+            left_action_items:
+                [['menu', lambda x: root.app.nav_drawer.set_state("open")]]
+            right_action_items:
+                [
+                ['close', lambda x: root.app.close_settings_action(self)],
+                ]
+            #    [['eye-off', lambda x: root.ids.screen_manager.app.announce_filter_action(self)]]
+
+        ScrollView:
+            id: announces_scrollview
+
+            MDBoxLayout:
+                orientation: "vertical"
+                spacing: "24dp"
+                size_hint_y: None
+                height: self.minimum_height
+                padding: dp(64)
+
+                MDLabel:
+                    id: announces_info
+                    markup: True
+                    text: ""
+                    size_hint_y: None
+                    text_size: self.width, None
+                    height: self.texture_size[1]
+"""
